@@ -1,9 +1,7 @@
 #include <config.h>
 
-#include <eel/eel-caption-table.h>
 #include <eel/eel-radio-button-group.h>
 #include <eel/eel-string-picker.h>
-#include <eel/eel-text-caption.h>
 #include <eel/eel-stock-dialogs.h>
 #include <gtk/gtk.h>
 #include <libgnomeui/gnome-ui-init.h>
@@ -28,9 +26,7 @@ create_pixbuf (const char *name)
 
 static void test_radio_group                     (void);
 static void test_radio_group_horizontal          (void);
-static void test_caption_table                   (void);
 static void test_string_picker                   (void);
-static void test_text_caption                    (void);
 static void test_ok_dialog                       (void);
 
 /* Callbacks */
@@ -38,12 +34,6 @@ static void test_radio_changed_callback          (GtkWidget *button_group,
 						  gpointer   user_data);
 static void string_picker_changed_callback       (GtkWidget *string_picker,
 						  gpointer   user_data);
-static void text_caption_changed_callback        (GtkWidget *text_caption,
-						  gpointer   user_data);
-static void test_caption_table_activate_callback (GtkWidget *button_group,
-						  gint       active_index,
-						  gpointer   user_data);
-
 int
 main (int argc, char * argv[])
 {
@@ -53,9 +43,7 @@ main (int argc, char * argv[])
 
 	test_radio_group ();
 	test_radio_group_horizontal ();
-	test_caption_table ();
 	test_string_picker ();
-	test_text_caption ();
 	test_ok_dialog ();
 
 	gtk_main ();
@@ -86,9 +74,9 @@ radio_group_load_it_up (EelRadioButtonGroup	*group,
 	{
 		GdkPixbuf *pixbufs[3];
 		
-		pixbufs[0] = create_pixbuf ("novice.png");
-		pixbufs[1] = create_pixbuf ("intermediate.png");
-		pixbufs[2] = create_pixbuf ("expert.png");
+		pixbufs[0] = create_pixbuf ("colors.png");
+		pixbufs[1] = create_pixbuf ("backgrounds.png");
+		pixbufs[2] = create_pixbuf ("emblems.png");
 		
 		eel_radio_button_group_set_entry_pixbuf (EEL_RADIO_BUTTON_GROUP (group), 0, pixbufs[0]);
 		eel_radio_button_group_set_entry_pixbuf (EEL_RADIO_BUTTON_GROUP (group), 1, pixbufs[1]);
@@ -149,57 +137,6 @@ test_radio_group_horizontal (void)
 	gtk_widget_show (window);
 }
 
-static void
-test_caption_table (void)
-{
-	GtkWidget * window;
-	GtkWidget * table;
-
-	window = gtk_window_new (GTK_WINDOW_TOPLEVEL);
-	gtk_window_set_title (GTK_WINDOW (window), "caption table test");
-
-	table = eel_caption_table_new (4);
-
-	eel_caption_table_set_row_info (EEL_CAPTION_TABLE (table),
-					     0,
-					     "Something",
-					     "Text",
-					     TRUE,
-					     FALSE);
-
-	eel_caption_table_set_row_info (EEL_CAPTION_TABLE (table),
-					     1,
-					     "ReadOnly",
-					     "Cant Change Me",
-					     TRUE,
-					     TRUE);
-
-	eel_caption_table_set_row_info (EEL_CAPTION_TABLE (table),
-					     2,
-					     "Password",
-					     "sekret",
-					     FALSE,
-					     FALSE);
-
-	eel_caption_table_set_row_info (EEL_CAPTION_TABLE (table),
-					     3,
-					     "This is a very long label",
-					     "Text",
-					     TRUE,
-					     FALSE);
-
-	g_signal_connect (table,
-			    "activate",
-			    G_CALLBACK (test_caption_table_activate_callback),
-			    (gpointer) NULL);
-
-	gtk_container_add (GTK_CONTAINER (window), table);
-
-	gtk_widget_show (table);
-
-	gtk_widget_show (window);
-}
-
 static void
 test_string_picker (void)
 {
@@ -238,31 +175,6 @@ test_string_picker (void)
 	gtk_widget_show_all (window);
 }
 
-static void
-test_text_caption (void)
-{
-	GtkWidget		*window;
-	GtkWidget		*picker;
-	
-	window = gtk_window_new (GTK_WINDOW_TOPLEVEL);
-	gtk_window_set_title (GTK_WINDOW (window), "text caption test");
-
-	picker = eel_text_caption_new ();
-	
-	eel_caption_set_title_label (EEL_CAPTION (picker), "Home Page:");
-
-	eel_text_caption_set_text (EEL_TEXT_CAPTION (picker), "file:///tmp");
-	
-	gtk_container_add (GTK_CONTAINER (window), picker);
-	
-	g_signal_connect (picker,
-			    "changed",
-			    G_CALLBACK (text_caption_changed_callback),
-			    (gpointer) NULL);
-
-	gtk_widget_show_all (window);
-}
-
 static void
 string_picker_changed_callback (GtkWidget *string_picker, gpointer user_data)
 {
@@ -278,21 +190,6 @@ string_picker_changed_callback (GtkWidget *string_picker, gpointer user_data)
 	g_free (text);
 }
 
-static void
-text_caption_changed_callback (GtkWidget *text_caption, gpointer user_data)
-{
-	char	  *text;
-
-	g_assert (text_caption != NULL);
-	g_assert (EEL_IS_TEXT_CAPTION (text_caption));
-
-	text = eel_text_caption_get_text (EEL_TEXT_CAPTION (text_caption));
-
-	g_print ("text_caption_changed_callback(%s)\n", text);
-	
-	g_free (text);
-}
-
 static void
 test_radio_changed_callback (GtkWidget *buttons, gpointer user_data)
 {
@@ -303,20 +200,21 @@ test_radio_changed_callback (GtkWidget *buttons, gpointer user_data)
 	g_print ("test_radio_changed_callback (%d)\n", i);
 }
 
-static void
-test_caption_table_activate_callback (GtkWidget  *button_group,
-				      gint        active_index,
-				      gpointer    user_data)
-{
-	g_print ("test_caption_table_activate_callback (active_index=%d)\n", active_index);
-}
-
 static void
 test_ok_dialog (void)
 {
 	GtkDialog *dialog;
 
+	dialog = eel_show_error_dialog_with_details ("Some test information",
+						     "the secondary text",
+						     "the dialog title",
+						     "the details text",
+						     NULL);
+	gtk_dialog_run (dialog);
+	gtk_widget_destroy (GTK_WIDGET (dialog));
+	
 	dialog = eel_show_info_dialog ("Some test information",
+				       "the secondary text",
 				       "the dialog title",
 				       NULL);
 	gtk_dialog_run (dialog);
